@@ -1,7 +1,9 @@
-import yaml
 import os
+import sys
 from pathlib import Path
 
+import yaml
+
 
 def merge_dicts(dict1, dict2):
     for k, v in dict1.items():
@@ -19,8 +21,10 @@ def get_existent_path(*paths):
         if path_object.exists():
             return path_object
 
-
-USERPROFILE_ANIMDL_PATH = os.getenv("userprofile", ".") + "/.animdl/config.yml"
+if sys.platform == "win32":
+    USERPROFILE_ANIMDL_PATH = os.getenv("userprofile", ".") + "/.animdl/config.yml"
+else:
+    USERPROFILE_ANIMDL_PATH = os.getenv("HOME", ".") + "/animdl/config.yml"
 
 CONFIGURATION_FILE_PATH = get_existent_path(
     os.getenv("ANIMDL_CONFIG", "./animdl_config.yml"),
@@ -97,6 +101,7 @@ DEFAULT_CONFIG = {
         "hls_download": False,
         "submerge": True,
     },
+    "discord_presence": False,
 }
 
 CONFIG = DEFAULT_CONFIG
@@ -151,3 +156,5 @@ QBITTORENT_CONFIG = CONFIG.get("qbittorrent", {})
 
 QBITTORENT_ENDPOINT = QBITTORENT_CONFIG.get("endpoint_url")
 QBITTORENT_CREDENTIALS = QBITTORENT_CONFIG.get("credentials", {})
+
+DISCORD_PRESENCE = CONFIG.get("discord_presence", False)
